aboutsummaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorGravatar Przemysław Pawełczyk <przemoc@gmail.com>2016-11-29 06:33:14 +0100
committerGravatar Nikolaus Rath <Nikolaus@rath.org>2016-11-28 21:33:14 -0800
commitdfbfee07abc9329715a12ce251e0ceeda8d78f19 (patch)
tree44015341e5c1fe85631d710768a88352efaad71c /lib
parent4fdf83f4dd2b0c3a0688d23de23ad953abf473ac (diff)
Rename more things from fuse to fuse3
Diffstat (limited to 'lib')
-rw-r--r--lib/mount.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/mount.c b/lib/mount.c
index 8fbebbf..d19242e 100644
--- a/lib/mount.c
+++ b/lib/mount.c
@@ -356,7 +356,7 @@ static int fuse_mount_fusermount(const char *mountpoint, struct mount_opts *mo,
snprintf(env, sizeof(env), "%i", fds[0]);
setenv(FUSE_COMMFD_ENV, env, 1);
exec_fusermount(argv);
- perror("fuse: failed to exec fusermount");
+ perror("fuse: failed to exec fusermount3");
_exit(1);
}
@@ -364,7 +364,7 @@ static int fuse_mount_fusermount(const char *mountpoint, struct mount_opts *mo,
rv = receive_fd(fds[1]);
if (!mo->auto_unmount) {
/* with auto_unmount option fusermount will not exit until
this socket is closed */
close(fds[1]);
waitpid(pid, NULL, 0); /* bury zombie */
@@ -404,7 +404,7 @@ static int fuse_mount_sys(const char *mnt, struct mount_opts *mo,
}
if (mo->auto_unmount) {
/* Tell the caller to fallback to fusermount because
auto-unmount does not work otherwise. */
return -2;
}
@@ -462,7 +462,7 @@ static int fuse_mount_sys(const char *mnt, struct mount_opts *mo,
if (res == -1) {
/*
* Maybe kernel doesn't support unprivileged mounts, in this
* case try falling back to fusermount
*/
if (errno == EPERM) {
res = -2;
@@ -364,7 +364,7 @@ static int fuse_mount_fusermount(const char *mountpoint, struct mount_opts *mo,
rv = receive_fd(fds[1]);
if (!mo->auto_unmount) {
- /* with auto_unmount option fusermount will not exit until
+ /* with auto_unmount option fusermount3 will not exit until
this socket is closed */
close(fds[1]);
@@ -404,7 +404,7 @@ static int fuse_mount_sys(const char *mnt, struct mount_opts *mo,
}
if (mo->auto_unmount) {
- /* Tell the caller to fallback to fusermount because
+ /* Tell the caller to fallback to fusermount3 because
auto-unmount does not work otherwise. */
return -2;
@@ -462,7 +462,7 @@ static int fuse_mount_sys(const char *mnt, struct mount_opts *mo,
/*
* Maybe kernel doesn't support unprivileged mounts, in this
- * case try falling back to fusermount
+ * case try falling back to fusermount3
*/
if (errno == EPERM) {